@@ -1,9 +1,10 @@
 package Test2::Formatter::TAP;
 use strict;
 use warnings;
-require PerlIO;
 
-our $VERSION = '1.302083';
+our $VERSION = '1.302085';
+
+use Test2::Util qw/clone_io/;
 
 use Test2::Util::HashBase qw{
     no_numbers handles _encoding last_fh
@@ -117,13 +118,9 @@ sub write {
 sub _open_handles {
     my $self = shift;
 
-    my %seen;
-    open(my $out, '>&', STDOUT) or die "Can't dup STDOUT:  $!";
-    binmode($out, join(":", "", "raw", grep { $_ ne 'unix' and !$seen{$_}++ } PerlIO::get_layers(STDOUT)));
-
-    %seen = ();
-    open(my $err, '>&', STDERR) or die "Can't dup STDERR:  $!";
-    binmode($err, join(":", "", "raw", grep { $_ ne 'unix' and !$seen{$_}++ } PerlIO::get_layers(STDERR)));
+    require Test2::API;
+    my $out = clone_io(Test2::API::test2_stdout());
+    my $err = clone_io(Test2::API::test2_stderr());
 
     _autoflush($out);
     _autoflush($err);
